==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeNodeList.h <==
// class gnu.xml.libxmlj.dom.GnomeNodeList

// class file dependencies
// @dep_class 39d3ee279e1f673f gnu_xml_libxmlj_dom_GnomeNodeList
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeNodeList_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeNodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jint _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *);
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *);
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *, jint);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods	gnu_xml_libxmlj_dom_GnomeNodeList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs {
	struct _jc_java_lang_Object$object	*id;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs	gnu_xml_libxmlj_dom_GnomeNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNodeList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object {
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype _jc_gnu_xml_libxmlj_dom_GnomeNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeNodeList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeNodeList_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeNodeList.h <==
// class gnu.xml.libxmlj.dom.GnomeNodeList

// class file dependencies
// @dep_class 39d3ee279e1f673f gnu_xml_libxmlj_dom_GnomeNodeList
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeNodeList_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeNodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vmethods	gnu_xml_libxmlj_dom_GnomeNodeList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs {
	struct _jc_java_lang_Object$object	*id;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_refs	gnu_xml_libxmlj_dom_GnomeNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNodeList$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNodeList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNodeList$object {
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeNodeList$vtype _jc_gnu_xml_libxmlj_dom_GnomeNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeNodeList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeNodeList_H_ */
